/* countdown-home-widget.h */

#ifndef _COUNTDOWN_HOME_WIDGET
#define _COUNTDOWN_HOME_WIDGET

#include <libhildondesktop/libhildondesktop.h>
#include <time.h> /* For tm. */

G_BEGIN_DECLS

#define COUNTDOWN_TYPE_HOME_WIDGET countdown_home_widget_get_type()

#define COUNTDOWN_HOME_WIDGET(obj) \
  (G_TYPE_CHECK_INSTANCE_CAST ((obj), COUNTDOWN_TYPE_HOME_WIDGET, CountdownHomeWidget))

#define COUNTDOWN_HOME_WIDGET_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_CAST ((klass), COUNTDOWN_TYPE_HOME_WIDGET, CountdownHomeWidgetClass))

#define COUNTDOWN_IS_HOME_WIDGET(obj) \
  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), COUNTDOWN_TYPE_HOME_WIDGET))

#define COUNTDOWN_IS_HOME_WIDGET_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_TYPE ((klass), COUNTDOWN_TYPE_HOME_WIDGET))

#define COUNTDOWN_HOME_WIDGET_GET_CLASS(obj) \
  (G_TYPE_INSTANCE_GET_CLASS ((obj), COUNTDOWN_TYPE_HOME_WIDGET, CountdownHomeWidgetClass))

typedef struct _CountdownHomeWidget        CountdownHomeWidget;
typedef struct _CountdownHomeWidgetClass   CountdownHomeWidgetClass;
typedef struct _CountdownHomeWidgetPrivate CountdownHomeWidgetPrivate;

struct _CountdownHomeWidget
{
  HDHomePluginItem parent;

  CountdownHomeWidgetPrivate *priv;
};

struct _CountdownHomeWidgetClass
{
  HDHomePluginItemClass  parent;
};

GType countdown_home_widget_get_type (void);

G_END_DECLS

#endif /* _COUNTDOWN_HOME_WIDGET */

